.. _mock_data:

Utilities for Mocking Geophysical Data (``pyzome.mock_data``)
=============================================================
Provides some simple utilities for generating mock geophysical data.
These include the automatic generation of coordinates such as 
latitudes and longitudes. These utilities are used internally 
for tests, but are also exposed publicly in case they are 
useful for users. 

Functions
---------
.. automodule:: pyzome.mock_data
   :members: